@@ -1,7 +1,8 @@
-from dataclasses import field
 from typing import List, Optional
 
-from ome_types.dataclasses import AUTO_SEQUENCE, ome_dataclass
+from pydantic import Field
+
+from ome_types._base_type import OMEType
 
 from .annotation_ref import AnnotationRef
 from .experimenter_ref import ExperimenterRef
@@ -9,8 +10,7 @@ from .leader import Leader
 from .simple_types import ExperimenterGroupID
 
 
-@ome_dataclass
-class ExperimenterGroup:
+class ExperimenterGroup(OMEType):
     """The ExperimenterGroupID is required.
 
     Information should ideally be specified for at least one Leader as a contact
@@ -18,18 +18,18 @@ class ExperimenterGroup:
 
     Parameters
     ----------
+    id : ExperimenterGroupID
     annotation_ref : AnnotationRef, optional
     description : str, optional
         A description for the group.
     experimenter_ref : ExperimenterRef, optional
-    id : ExperimenterGroupID
     leader : Leader, optional
     name : str, optional
     """
 
-    annotation_ref: List[AnnotationRef] = field(default_factory=list)
+    id: ExperimenterGroupID
+    annotation_ref: List[AnnotationRef] = Field(default_factory=list)
     description: Optional[str] = None
-    experimenter_ref: List[ExperimenterRef] = field(default_factory=list)
-    id: ExperimenterGroupID = AUTO_SEQUENCE  # type: ignore
-    leader: List[Leader] = field(default_factory=list)
+    experimenter_ref: List[ExperimenterRef] = Field(default_factory=list)
+    leader: List[Leader] = Field(default_factory=list)
     name: Optional[str] = None
