@@ -1,13 +1,12 @@
 from typing import Optional
 
-from ome_types.dataclasses import ome_dataclass
+from ome_types._base_type import OMEType
 
 from .light_source import LightSource
 from .map import Map
 
 
-@ome_dataclass
-class GenericExcitationSource(LightSource):
+class GenericExcitationSource(LightSource, OMEType):
     """The GenericExcitationSource element is used to represent a source as a
     collection of key/value pairs, stored in a Map.
 
@@ -16,11 +15,11 @@ class GenericExcitationSource(LightSource):
 
     Parameters
     ----------
-    annotation_ref : AnnotationRef, optional
     id : LightSourceID
         A LightSource ID must be specified for each light source, and the
         individual light sources can be referred to by their LightSource IDs
         (eg from Channel).
+    annotation_ref : AnnotationRef, optional
     lot_number : str, optional
         The lot number of the component.
     manufacturer : str, optional
