@@ -1,11 +1,10 @@
-from ome_types.dataclasses import EMPTY, ome_dataclass
+from ome_types._base_type import OMEType
 
 from .reference import Reference
 from .simple_types import ImageID
 
 
-@ome_dataclass
-class ImageRef(Reference):
+class ImageRef(Reference, OMEType):
     """The ImageRef element is a reference to an Image element.
 
     Parameters
@@ -13,4 +12,4 @@ class ImageRef(Reference):
     id : ImageID
     """
 
-    id: ImageID = EMPTY  # type: ignore
+    id: ImageID
