@@ -1,15 +1,15 @@
-from dataclasses import field
 from typing import List, Optional
 
-from ome_types.dataclasses import ome_dataclass
+from pydantic import Field
+
+from ome_types._base_type import OMEType
 
 from .annotation_ref import AnnotationRef
 from .dichroic_ref import DichroicRef
 from .filter_ref import FilterRef
 
 
-@ome_dataclass
-class LightPath:
+class LightPath(OMEType):
     """A description of the light path
 
     Parameters
@@ -22,7 +22,7 @@ class LightPath:
         The Filters placed in the Excitation light path.
     """
 
-    annotation_ref: List[AnnotationRef] = field(default_factory=list)
+    annotation_ref: List[AnnotationRef] = Field(default_factory=list)
     dichroic_ref: Optional[DichroicRef] = None
-    emission_filter_ref: List[FilterRef] = field(default_factory=list)
-    excitation_filter_ref: List[FilterRef] = field(default_factory=list)
+    emission_filter_ref: List[FilterRef] = Field(default_factory=list)
+    excitation_filter_ref: List[FilterRef] = Field(default_factory=list)
