@@ -1,10 +1,9 @@
-from ome_types.dataclasses import ome_dataclass
+from ome_types._base_type import OMEType
 
 from .annotation import Annotation
 
 
-@ome_dataclass
-class ListAnnotation(Annotation):
+class ListAnnotation(Annotation, OMEType):
     """This annotation is a grouping object.
 
     It uses the sequence of annotation refs from the base Annotation to form the
@@ -12,6 +11,7 @@ class ListAnnotation(Annotation):
 
     Parameters
     ----------
+    id : AnnotationID
     annotation_ref : AnnotationRef, optional
     annotator : ExperimenterID, optional
         The Annotator is the person who attached this annotation. e.g. If
@@ -19,7 +19,6 @@ class ListAnnotation(Annotation):
         the Annotator.
     description : str, optional
         A description for the annotation.
-    id : AnnotationID
     namespace : str, optional
         We recommend the inclusion of a namespace for annotations you define.
         If it is absent then we assume the annotation is to use our (OME's)
